summaryrefslogtreecommitdiff
path: root/lua.h
diff options
context:
space:
mode:
authorRoberto Ierusalimschy <roberto@inf.puc-rio.br>2004-09-15 17:39:42 -0300
committerRoberto Ierusalimschy <roberto@inf.puc-rio.br>2004-09-15 17:39:42 -0300
commit2419f2bf02a9165471248f09bae57e3fa134e545 (patch)
tree9f7e387740892ee591218b8ea745d35a45aa6e41 /lua.h
parent0e54d2be365ec77cb455e0d0f3c5c6f9efa6e04c (diff)
downloadlua-github-2419f2bf02a9165471248f09bae57e3fa134e545.tar.gz
cleaner API for coroutines
Diffstat (limited to 'lua.h')
-rw-r--r--lua.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/lua.h b/lua.h
index 0b5347d6..66095219 100644
--- a/lua.h
+++ b/lua.h
@@ -1,5 +1,5 @@
/*
-** $Id: lua.h,v 1.191 2004/06/02 17:37:03 roberto Exp roberto $
+** $Id: lua.h,v 1.192 2004/06/04 15:30:53 roberto Exp roberto $
** Lua - An Extensible Extension Language
** Tecgraf: Computer Graphics Technology Group, PUC-Rio, Brazil
** http://www.lua.org mailto:info@lua.org
@@ -37,11 +37,12 @@
#define lua_upvalueindex(i) (LUA_GLOBALSINDEX-(i))
/* error codes for `lua_pcall' */
#define LUA_ERRRUN 1
#define LUA_ERRSYNTAX 2
#define LUA_ERRMEM 3
#define LUA_ERRERR 4
typedef struct lua_State lua_State;
@@ -165,6 +166,7 @@ LUA_API const char *lua_pushfstring (lua_State *L, const char *fmt, ...);
LUA_API void lua_pushcclosure (lua_State *L, lua_CFunction fn, int n);
LUA_API void lua_pushboolean (lua_State *L, int b);
LUA_API void lua_pushlightuserdata (lua_State *L, void *p);
+LUA_API int lua_pushthread (lua_State *L);
/*
@@ -208,6 +210,7 @@ LUA_API int lua_dump (lua_State *L, lua_Chunkwriter writer, void *data);
*/
LUA_API int lua_yield (lua_State *L, int nresults);
LUA_API int lua_resume (lua_State *L, int narg);
+LUA_API int lua_threadstatus (lua_State *L);
/*
** garbage-collection function and options
@@ -37,11 +37,12 @@
#define lua_upvalueindex(i) (LUA_GLOBALSINDEX-(i))
-/* error codes for `lua_pcall' */
-#define LUA_ERRRUN 1
-#define LUA_ERRSYNTAX 2
-#define LUA_ERRMEM 3
-#define LUA_ERRERR 4
+/* return codes for `lua_pcall', `lua_resume', and `lua_threadstatus' */
+#define LUA_YIELD 1
+#define LUA_ERRRUN 2
+#define LUA_ERRSYNTAX 3
+#define LUA_ERRMEM 4
+#define LUA_ERRERR 5
typedef struct lua_State lua_State;